# ⛲ fontain ⛲

fontain is a Python tool for font recognition on images

# Installation
```pip install fontain```

# Usage

## API

```python
from fontain import *
```

## CLI
```
fontain [-h] path

Recognize font on image

positional arguments:
  path                  input file path

optional arguments:
  -h, --help            show this help message and exit
```

# Example

# License
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
